@@ -106,7 +106,7 @@ class Connection:
 
     def __init__(self, dsn, loop, timeout, waiter, echo, **kwargs):
         self._loop = loop
-        self._conn = psycopg2.connect(dsn, async=True, **kwargs)
+        self._conn = psycopg2.connect(dsn, async_=True, **kwargs)
         self._dsn = self._conn.dsn
         assert self._conn.isexecuting(), "Is conn an async at all???"
         self._fileno = self._conn.fileno()
@@ -258,7 +258,7 @@ class Connection:
         """A coroutine that returns a new cursor object using the connection.
 
         *cursor_factory* argument can be used to create non-standard
-         cursors. The argument must be suclass of
+         cursors. The argument must be subclass of
          `psycopg2.extensions.cursor`.
 
         *name*, *scrollable* and *withhold* parameters are not supported by
